@@ -8,7 +8,7 @@ Used e.g. by :ref:`welfare`.
 
 """
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
 from django.conf import settings
 
