@@ -7,7 +7,7 @@ import logging ; logger = logging.getLogger(__name__)
 from django.db import models
 from django.db.models import Q
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from lino.api import dd, rt
 
 from lino import mixins
