@@ -1,15 +1,17 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2018 Rumma & Ko Ltd
+# Copyright 2012-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 
 """Utilities for this plugin.
 
+See :doc:`/specs/ledger`
 
 """
 
 from decimal import Decimal, ROUND_HALF_UP
 from lino.api import _
+from .choicelists import DC
 
 ZERO = Decimal(0)
 CENT = Decimal('.01')
@@ -17,16 +19,17 @@ HUNDRED = Decimal('100.00')
 ONE = Decimal('1.00')
 MAX_AMOUNT = Decimal("9999999.00")
 
-DEBIT = False
-CREDIT = True
+# DC.debit = False
+# DC.credit = True
+#
+# DCLABELS = {
+#     DC.debit: _("Debit"),
+#     DC.credit: _("Credit")
+# }
 
-DCLABELS = {
-    DEBIT: _("Debit"),
-    CREDIT: _("Credit")
-}
 
 class Balance(object):
-    
+
     def __init__(self, d, c):
         if d is None: d = ZERO
         if c is None: c = ZERO
@@ -41,18 +44,18 @@ class Balance(object):
         if self.d:
             return "{} DB".format(self.d)
         return "{} CR".format(self.c)
-    
+
     def __repr__(self):
         return "Balance({},{})".format(self.d, self.c)
         return "{} CR".format(self.c)
-    
+
     def __sub__(self, o):
         d1 = self.d or ZERO
         c1 = self.c or ZERO
         d2 = o.d or ZERO
         c2 = o.c or ZERO
         return Balance(d1-d2, c1-c2)
-    
+
     def __add__(self, o):
         d1 = self.d or ZERO
         c1 = self.c or ZERO
@@ -61,13 +64,11 @@ class Balance(object):
         return Balance(d1+d2, c1+c2)
 
     def value(self, dc):
-        if dc is DEBIT:
+        if dc is DC.debit:
             return self.d - self.c
         else:
             return self.c - self.d
-    
+
 
 def myround(d):
     return d.quantize(CENT, rounding=ROUND_HALF_UP)
-
-
