@@ -4,7 +4,7 @@
 # License: BSD (see file COPYING for details)
 "Choicelists for :mod:`lino_xl.lib.outbox`."
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from lino.api import dd
 
 
