@@ -16,7 +16,7 @@ To use it, simply add the following line to your
 
 from lino import ad
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class Plugin(ad.Plugin):
