@@ -3,7 +3,7 @@
 # License: BSD (see file COPYING for details)
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
 
 from etgen import html as xghtml
