@@ -36,7 +36,7 @@ import datetime
 from django.db import models
 from django.db.models import Q
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils import timezone
 from django.contrib.humanize.templatetags.humanize import naturaltime
 
