@@ -10,7 +10,7 @@ from builtins import str
 
 import six
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.conf import settings
 
 from lino.api import dd
