@@ -31,7 +31,7 @@ Product = dd.resolve_model('products.Product')
 Client = rt.models.tera.Client
 Course = rt.models.courses.Course
 Line = rt.models.courses.Line
-CourseAreas = rt.models.courses.CourseAreas
+ActivityLayouts = rt.models.courses.ActivityLayouts
 Course = rt.models.courses.Course
 Enrolment = rt.models.courses.Enrolment
 Event = rt.models.cal.Event
